<?php

function get_events_for_display() {

    if(!wp_verify_nonce($_REQUEST['nonce'], "get_events_for_display_nonce")) {
		exit('Move along, nothing to see here.');
	}

    $event_listings = array();

    $events = get_posts(array(
        'post_type' 		=> 'event',
        'posts_per_page' 	=> -1,
        'suppress_filters'  => false,
        'meta_query' 		=> array(
            'relation'  => 'AND',
            array(
                'key'       => 'event_status',
                'compare'   => '!=',
                'value'     => 'draft'
            ),
            array(
                'key'       => 'event_visibility',
                'compare'   => '=',
                'value'     => true
            ),
            array(
                'key'       => 'event_organiser',
                'compare'   => '=',
                'value'     => $_REQUEST['organiser'],
            ), 
        ),
    ));

    if($events) {

        foreach($events as $event) {
            $event_dates = get_field('event_series_dates', $event);
            if($event_dates) {
                
                $sorted_dates = array();
                foreach($event_dates as $event_date) {
                    
                    $start_date = $event_date['event_series_start_datetime'];
                    if(strtotime($start_date) >= strtotime("today")) {
                        $dateObject = new DateTime($start_date);
                        array_push($sorted_dates, $dateObject);
                    }
                    
                }

                if(count($sorted_dates) > 0) {
                    usort($sorted_dates, function ($a, $b) {
                        return $a->format('Y-m-d H:i:s') <=> $b->format('Y-m-d H:i:s');
                    });

                    $event_id = $event->ID;
                    $title = get_the_title($event_id);
                    $next_event_date = $sorted_dates[0]->format('Y-m-d H:i:s');
                    $next_date = date("D, jS M Y", strtotime($next_event_date));
                    $next_time = date("g:ia", strtotime($next_event_date));
                    $fields = get_fields($event_id);
                    $featured_image = isset($fields['featured_image']) ? $fields['featured_image'] : null;
                    $summary = $fields['event_summary'];
                    $series = $fields['is_event_series'];
                    $link = get_the_permalink($event_id);

                    $ev = array(
                        'event_id'  => $event_id,
                        'title'     => $title,
                        'next_date' => $next_date,
                        'next_time' => $next_time,
                        'image'     => $featured_image,
                        'summary'   => $summary,  
                        'is_series' => $series,
                        'link'      => $link,
                    );

                    array_push($event_listings, $ev);
                }

            }
        }

    }
    
    wp_send_json($event_listings);

}
add_action("wp_ajax_get_events_for_display", "get_events_for_display");
add_action("wp_ajax_nopriv_get_events_for_display", "get_events_for_display");

